@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use 5.008003;
 
-our $VERSION = '1.120';
+our $VERSION = '1.200';
 use Exporter 'import';
 our @EXPORT_OK = qw( choose );
 
@@ -524,14 +524,28 @@ sub choose {
         }
         elsif ( $key == CONTROL_SPACE ) {
             if ( $self->{wantarray} ) {
-                for my $i ( 0 .. $#{$self->{rc2idx}} ) {
-                    for my $j ( 0 .. $#{$self->{rc2idx}[$i]} ) {
-                        $self->{marked}[$i][$j] = $self->{marked}[$i][$j] ? 0 : 1;
+                if ( $self->{pos}[ROW] == 0 ) {
+                    for my $i ( 0 .. $#{$self->{rc2idx}} ) {
+                        for my $j ( 0 .. $#{$self->{rc2idx}[$i]} ) {
+                            $self->{marked}[$i][$j] = $self->{marked}[$i][$j] ? 0 : 1;
+                        }
                     }
                 }
-                $self->__idx_to_marked( $self->{no_spacebar}, 0 ) if defined $self->{no_spacebar};
+                else {
+                    for my $i ( $self->{p_begin} .. $self->{p_end} ) {
+                        for my $j ( 0 .. $#{$self->{rc2idx}[$i]} ) {
+                            $self->{marked}[$i][$j] = $self->{marked}[$i][$j] ? 0 : 1;
+                        }
+                    }
+                }
+                if ( defined $self->{no_spacebar} ) {
+                    $self->__idx_to_marked( $self->{no_spacebar}, 0 );
+                }
                 $self->__wr_screen();
             }
+            else {
+                $self->__beep();
+            }
         }
         else {
             $self->__beep();
@@ -1110,7 +1124,7 @@ Term::Choose - Choose items from a list interactively.
 
 =head1 VERSION
 
-Version 1.120
+Version 1.200
 
 =cut
 
@@ -1239,7 +1253,8 @@ If C<choose> is called in an I<list context>, the user can also mark an item wit
 C<choose> then returns - when C<Return> is pressed - the list of marked items including the highlighted item.
 
 In I<list context> C<Ctrl-SpaceBar> (or C<Ctrl-@>) inverts the choices: marked items are unmarked and unmarked items are
-marked.
+marked. If the cursor is on the first row, C<Ctrl-SpaceBar> inverts the choices for the whole list else C<Ctrl-SpaceBar>
+inverts the choices for the current page.
 
 =item
 
